@@ -1,5 +1,6 @@
 import logging
 import os
+import onnx
 from onnxcli.common import SubCmd
 
 logger = logging.getLogger('onnxcli')
@@ -11,8 +12,8 @@ class OptimizeCmd(SubCmd):
     subcmd = 'optimize'
 
     def add_args(self, subparser):
-        subparser.add_argument('input_path', type=str, help="The input ONNX model")
-        subparser.add_argument('output_path', type=str, help="The output ONNX model")
+        subparser.add_argument('input_path', type=str, help="The path to the input ONNX model")
+        subparser.add_argument('output_path', type=str, help="The path to the output ONNX model")
         subparser.add_argument(
             '-p',
             '--passes',
@@ -24,14 +25,17 @@ class OptimizeCmd(SubCmd):
 
     def run(self, args):
         logger.info("Running <Optimization> on model {}".format(args.input_path))
-        import onnx
-        import onnxoptimizer
+        try:
+            import onnxoptimizer
+        except ImportError as err:
+            logger.error("Failed to import. Try to fix with `onnx setup`.")
+            raise err
 
         if not os.path.exists(args.input_path):
             raise ValueError("Invalid input model path: {}".format(args.input_path))
         if len(args.passes) == 0:
             passes = onnxoptimizer.get_available_passes()
-            logger.warn("No optimization passes specified, running all available passes: {}".format(passes))
+            logger.warning("No optimization passes specified, running all available passes: {}".format(passes))
         else:
             passes = args.passes
             logger.info("Running with passes: {}".format(passes))
